@@ -7,7 +7,7 @@ require "minitest/parallel"
 # :include: README.txt
 
 module Minitest
-  VERSION = "5.2.1" # :nodoc:
+  VERSION = "5.4.0" # :nodoc:
 
   @@installed_at_exit ||= false
   @@after_run = []
@@ -138,7 +138,7 @@ module Minitest
   # loaded if a Runnable calls parallelize_me!.
 
   def self.__run reporter, options
-    suites = Runnable.runnables
+    suites = Runnable.runnables.shuffle
     parallel, serial = suites.partition { |s| s.test_order == :parallel }
 
     # If we run the parallel tests before the serial tests, the parallel tests
@@ -763,4 +763,3 @@ module Minitest
 end
 
 require "minitest/test"
-require "minitest/unit" unless defined?(MiniTest) # compatibility layer only
