@@ -1,6 +1,4 @@
-#!/usr/bin/ruby -w
-
-require 'minitest/unit'
+require "minitest/test"
 
 class Module # :nodoc:
   def infect_an_assertion meth, new_name, dont_flip = false # :nodoc:
@@ -56,13 +54,13 @@ module Kernel # :nodoc:
   #
   # For more information about expectations, see Minitest::Expectations.
 
-  def describe desc, additional_desc = nil, &block # :doc:
+  def describe desc, *additional_desc, &block # :doc:
     stack = Minitest::Spec.describe_stack
-    name  = [stack.last, desc, additional_desc].compact.join("::")
+    name  = [stack.last, desc, *additional_desc].compact.join("::")
     sclas = stack.last || if Class === self && is_a?(Minitest::Spec::DSL) then
                             self
                           else
-                            Minitest::Spec.spec_type desc
+                            Minitest::Spec.spec_type desc, *additional_desc
                           end
 
     cls = sclas.create name, desc
@@ -134,10 +132,10 @@ class Minitest::Spec < Minitest::Test
     #
     #     spec_type("BlahController") # => Minitest::Spec::Rails
 
-    def spec_type desc
+    def spec_type desc, *additional
       TYPES.find { |matcher, klass|
         if matcher.respond_to? :call then
-          matcher.call desc
+          matcher.call desc, *additional
         else
           matcher === desc.to_s
         end
@@ -223,7 +221,14 @@ class Minitest::Spec < Minitest::Test
     # Why use let instead of def? I honestly don't know.
 
     def let name, &block
-      raise ArgumentError, 'name cannot begin with "test"' if name.to_s =~ /\Atest/
+      name = name.to_s
+      pre, post = "let '#{name}' cannot ", ". Please use another name."
+      methods = Minitest::Spec.instance_methods.map(&:to_s) - %w[subject]
+      raise ArgumentError, "#{pre}begin with 'test'#{post}" if
+        name =~ /\Atest/
+      raise ArgumentError, "#{pre}override a method in Minitest::Spec#{post}" if
+        methods.include? name
+
       define_method name do
         @_memoized ||= {}
         @_memoized.fetch(name) { |k| @_memoized[k] = instance_eval(&block) }
@@ -262,6 +267,18 @@ class Minitest::Spec < Minitest::Test
     # :stopdoc:
     attr_reader :desc
     alias :specify :it
+
+    module InstanceMethods
+      def before_setup
+        super
+        Thread.current[:current_spec] = self
+      end
+    end
+
+    def self.extended obj
+      obj.send :include, InstanceMethods
+    end
+
     # :startdoc:
   end
 
