@@ -553,9 +553,23 @@ describe Minitest::Spec, :let do
   end
 
   it 'raises an error if the name begins with "test"' do
-    describe "let" do
-      proc { let(:test_value) { true } }.must_raise ArgumentError
-    end
+    proc { self.class.let(:test_value) { true } }.must_raise ArgumentError
+  end
+
+  it 'raises an error if the name shadows a normal instance method' do
+    proc { self.class.let(:message) { true } }.must_raise ArgumentError
+  end
+
+  it "doesn't raise an error if it is just another let" do
+    proc do
+      describe :outer do
+        let(:bar)
+        describe :inner do
+          let(:bar)
+        end
+      end
+      :good
+    end.call.must_equal :good
   end
 
   it 'procs come after dont_flip' do
@@ -660,19 +674,43 @@ class TestMeta < MetaMetaMetaTestCase
     Minitest::Spec.register_spec_type MiniSpecB do |desc|
       desc.superclass == ExampleA
     end
+    Minitest::Spec.register_spec_type MiniSpecC do |desc, *addl|
+      addl.include? :woot
+    end
 
     assert_equal MiniSpecA, Minitest::Spec.spec_type(ExampleA)
     assert_equal MiniSpecB, Minitest::Spec.spec_type(ExampleB)
+    assert_equal MiniSpecC, Minitest::Spec.spec_type(ExampleB, :woot)
   ensure
     Minitest::Spec::TYPES.replace original_types
   end
 
+  def test_bug_dsl_expectations
+    spec_class = Class.new MiniSpecB do
+      it "should work" do
+        0.must_equal 0
+      end
+    end
+
+    test_name = spec_class.instance_methods.sort.grep(/test/).first
+
+    spec = spec_class.new test_name
+
+    result = spec.run
+
+    assert spec.passed?
+    assert result.passed?
+    assert_equal 1, result.assertions
+  end
+
   def test_name
     spec_a = describe ExampleA do; end
     spec_b = describe ExampleB, :random_method do; end
+    spec_c = describe ExampleB, :random_method, :addl_context do; end
 
     assert_equal "ExampleA", spec_a.name
     assert_equal "ExampleB::random_method", spec_b.name
+    assert_equal "ExampleB::random_method::addl_context", spec_c.name
   end
 
   def test_name2
@@ -759,8 +797,9 @@ class TestSpecInTestCase < MetaMetaMetaTestCase
   def setup
     super
 
+    Thread.current[:current_spec] = self
     @tc = self
-    @assertion_count = 1
+    @assertion_count = 2
   end
 
   def assert_triggered expected, klass = Minitest::Assertion
@@ -792,8 +831,8 @@ class TestSpecInTestCase < MetaMetaMetaTestCase
   end
 
   def test_expectation_with_a_message
-    assert_triggered "Expected: 2\n  Actual: 1" do
-      1.must_equal 2, ""
+    assert_triggered "woot.\nExpected: 2\n  Actual: 1" do
+      1.must_equal 2, "woot"
     end
   end
 end
